==> makeen-expressionengine-0.0.51.tgz: package/testCases/testContext.ts <==
import { makeenBindingContext } from "../src/bindingContext";
import { outputVariables } from "../src/utils/outputVariables";
import List from "typescript-dotnet-commonjs/System/Collections/List";
import DateTime from "typescript-dotnet-commonjs/System/Time/DateTime";
import { EntityObject } from "../src/utils/entityObject";
import { DictionaryObject as Dictionary } from '../src/utils/dictionaryObject'

export class testContext extends makeenBindingContext {
    getItem(key: string): Object {
        throw new Error("Method not implemented.");
    }
    ArrayString: string[] | undefined;
    private static instance: testContext;

    firstNumber: number = 0;
    firstBool: boolean = false;
    FirstString: string | undefined;
    SecondString: string | undefined;

    ThirdString: string | undefined;
    FourString: string | undefined;

    //firstNumber: number | undefined;
    secondNumber: number | undefined;
    thirdNumber: number | undefined;
    forthNumber: number | undefined;
    dtTime: DateTime | undefined;
    dtTime1: Date | undefined;


    boolTest: boolean = false;
    SubList: List<SubContext> = new List<SubContext>();
    List: List<Object> = new List<Object>();
    static getInstance(): testContext {
        if (!testContext.instance) {
            testContext.instance = new testContext();
        }

        return testContext.instance;
    }
    Controls: Dictionary = new Dictionary();
    // get Controls(): Dictionary<string, Control> {
    //     return this._controls;
    // }

    // set Controls(value: Dictionary<string, Control>) {
    //     this._controls = value;
    // }

    Entity: Dictionary = new Dictionary();

    protected resolveIndexer(key: string, resolved: outputVariables, setValue: Object | null, doSet: boolean): Object | undefined {
        //throw new Error("Method not implemented.");
        return undefined;
    }
    protected getKeys(): List<string> | undefined {
        //throw new Error("Method not implemented.");
        return undefined;
    }

}

class SubContext {
    constructor(name: string, address: string, age: number) {
        this.Name = name;
        this.Address = address;
        this.Age = age;
    }
    Name: string = "";
    Address: string = "";
    Age: number = 0;
}


export class Control {
    IsToggled: boolean = false;
    Text : string | null = "";
    ValueInt: number = 0;
    Value: number = 0;
    SelectedItem: object = new Object();
    SelectedItems: List<object> = new List<Object>();
    Descriptions :string ="";
    VarTest = "true";
}


export function getContext() {
    let context: testContext = testContext.getInstance();
    let con = new Control();
    con.Text = "Employee 50";
    con.Value = 20;
    if (!context.Controls.containsKey("nndm_textbox"))
        context.Controls.add("nndm_textbox", con);
    let con1 = new Control();
    con1.Text = "1";
    if (!context.Controls.containsKey("NonNegativeNumbers"))
        context.Controls.add("NonNegativeNumbers", con1);
    let con2 = new Control();
    con2.SelectedItem = { email: "test" };
    if (!context.Controls.containsKey("BusinessUnit"))
        context.Controls.add("BusinessUnit", con2);

    let con3 = new Control();
    con3.Text = null;
    con3.IsToggled = true;
    con3.Descriptions = "No";
    if (!context.Controls.containsKey("txtFees"))
        context.Controls.add("txtFees", con3);
    context.FirstString = "ab cd";
    context.firstNumber = 0;
    context.secondNumber = 2;
    context.thirdNumber = 3;
    context.forthNumber = 4;
    context.firstBool = true;
    context.boolTest = false;
    context.ArrayString = ["First", "Seconds", "Third", "Forth"]
    context.SubList = new List<SubContext>();
    context.SubList.add(new SubContext("name 1", "Address 1", 10));
    context.SubList.add(new SubContext("name 2", "Address 2", 20));
    context.SubList.add(new SubContext("name 3", "Address 1", 30));
    context.SubList.add(new SubContext("name 4", "Address 2", 40));
    context.SubList.add(new SubContext("name 1", "Address 1", 50));
    context.SubList.add(new SubContext("name 2", "Address 2", 60));
    context.dtTime = DateTime.now;
    context.dtTime1 = new Date(Date.now());


    context.Entity = new Dictionary();
    context.Entity.add("Employee", new List<EntityObject>());
    context.Entity.add("Project", new List<EntityObject>());
    context.Entity.add("EmployeeProject", new List<EntityObject>());
    let age = 10;
    for (let index = 0; index < 100; index++) {
        let dict: Dictionary = new Dictionary();
        dict.add("ID", index);
        dict.add("Name", ("Employee " + index));
        dict.add("modified", new Date(Date.now()))

        if (index % 10 == 0) {
            age = age * 2;
        }
        dict.add("Age", (age));
        dict.add("modified", Date.now()+age)

        let a: List<EntityObject> = context.Entity.getValue("Employee") as List<EntityObject>;
        a.add(new EntityObject(dict));
    }

    for (let index = 0; index < 10; index++) {
        let dict: Dictionary = new Dictionary();
        dict.add("ID", index);
        dict.add("Name", "Project " + index);
        let a: List<EntityObject> = context.Entity.getValue("Project") as List<EntityObject>;
        a.add(new EntityObject(dict));
    }
    let num = 0
    for (let index = 0; index < 20; index++) {
        let dict: Dictionary = new Dictionary();
        dict.add("ID", index);
        dict.add("Name", "Project " + index);
        if (index % 10 == 0) {
            num = ++num;
        }
        dict.add("EmployeeID", num);
        dict.add("ProjectID", num);

        let a: List<EntityObject> = context.Entity.getValue("EmployeeProject") as List<EntityObject>;
        a.add(new EntityObject(dict));
    }


    return context;
}

export class JoinTest {

    Entity?: Dictionary;
}

export interface IModel {
}

export class Employee implements IModel {

    ID?: number;

    Name?: string;

    JoiningDate?: DateTime;
}
export class EmployeeProject implements IModel {

    EmployeeID?: number;

    ProjectID?: number;
}

export class Project implements IModel {

    Name?: string;

    ID?: number;
}

==> makeen-expressionengine-0.0.63.tgz: package/testCases/testContext.ts <==
import { makeenBindingContext } from "../src/bindingContext";
import { outputVariables } from "../src/utils/outputVariables";
import List from "typescript-dotnet-commonjs/System/Collections/List";
import DateTime from "typescript-dotnet-commonjs/System/Time/DateTime";
import { EntityObject } from "../src/utils/entityObject";
import { DictionaryObject as Dictionary, DictionaryObject } from '../src/utils/dictionaryObject'

export class testContext extends makeenBindingContext {
    getItem(key: string): Object {
        throw new Error("Method not implemented.");
    }
    ArrayString: string[] | undefined;
    private static instance: testContext;

    firstNumber: number = 0;
    firstBool: boolean = false;
    FirstString: string | undefined;
    SecondString: string | undefined;

    ThirdString: string | undefined;
    FourString: string | undefined;

    //firstNumber: number | undefined;
    secondNumber: number | undefined;
    thirdNumber: number | undefined;
    forthNumber: number | undefined;
    dtTime: DateTime | undefined;
    dtTime1: Date | undefined;


    boolTest: boolean = false;
    SubList: List<SubContext> = new List<SubContext>();
    List: List<Object> = new List<Object>();
    static getInstance(): testContext {
        if (!testContext.instance) {
            testContext.instance = new testContext();
        }

        return testContext.instance;
    }
    Controls: Dictionary = new Dictionary();
    // get Controls(): Dictionary<string, Control> {
    //     return this._controls;
    // }

    // set Controls(value: Dictionary<string, Control>) {
    //     this._controls = value;
    // }

    Entity: Dictionary = new Dictionary();
    Var = new DictionaryObject();
    protected resolveIndexer(key: string, resolved: outputVariables, setValue: Object | null, doSet: boolean): Object | undefined {
        //throw new Error("Method not implemented.");
        return undefined;
    }
    protected getKeys(): List<string> | undefined {
        //throw new Error("Method not implemented.");
        return undefined;
    }

}

class SubContext {
    constructor(name: string, address: string, age: number) {
        this.Name = name;
        this.Address = address;
        this.Age = age;
    }
    Name: string = "";
    Address: string = "";
    Age: number = 0;
}


export class Control {
    IsToggled: boolean = false;
    Text : any = "";
    ValueInt: number = 0;
    Value: number = 0;
    SelectedItem: object = new Object();
    SelectedItems: List<object> = new List<Object>();
    Descriptions :string| null="";
    VarTest = "true";
}


export function getContext() {
    let context: testContext = testContext.getInstance();
    let con = new Control();
    con.Text = undefined;
    con.Value = 20;
    if (!context.Controls.containsKey("nndm_textbox"))
        context.Controls.add("nndm_textbox", con);
    let con1 = new Control();
    con1.Text = "1";
    if (!context.Controls.containsKey("NonNegativeNumbers"))
        context.Controls.add("NonNegativeNumbers", con1);
    let con2 = new Control();
    con2.SelectedItem = { email: "test" };
    if (!context.Controls.containsKey("BusinessUnit"))
        context.Controls.add("BusinessUnit", con2);

    let con3 = new Control();
    con3.Text = "Employee 1900";
    con3.IsToggled = true;
    con3.Value =899;
    con3.Descriptions = "Yes";
    if (!context.Controls.containsKey("txtFees"))
        context.Controls.add("txtFees", con3);
    context.FirstString = "ab cd";
    context.firstNumber = 0;
    context.secondNumber = 2;
    context.thirdNumber = 3;
    context.forthNumber = 4;
    context.firstBool = true;
    context.boolTest = false;
    context.ArrayString = ["First", "Seconds", "Third", "Forth"]
    context.SubList = new List<SubContext>();
    context.SubList.add(new SubContext("name 1", "Address 1", 10));
    context.SubList.add(new SubContext("name 2", "Address 2", 20));
    context.SubList.add(new SubContext("name 3", "Address 1", 30));
    context.SubList.add(new SubContext("name 4", "Address 2", 40));
    context.SubList.add(new SubContext("name 1", "Address 1", 50));
    context.SubList.add(new SubContext("name 2", "Address 2", 60));
    context.dtTime = DateTime.now;
    context.dtTime1 = new Date(Date.now());


    context.Entity = new Dictionary();
    context.Entity.add("Employee", new List<EntityObject>());
    context.Entity.add("Project", new List<EntityObject>());
    context.Entity.add("EmployeeProject", new List<EntityObject>());
    let age = 10;
    for (let index = 0; index < 100; index++) {
        let dict: Dictionary = new Dictionary();
        dict.add("ID", index);
        dict.add("Name", ("Employee " + index));
        dict.add("modified", new Date(Date.now()))

        if (index % 10 == 0) {
            age = age * 2;
        }
        dict.add("Age", (age));
        dict.add("modified", Date.now()+age)

        let a: List<EntityObject> = context.Entity.getValue("Employee") as List<EntityObject>;
        a.add(new EntityObject(dict));
    }

    for (let index = 0; index < 10; index++) {
        let dict: Dictionary = new Dictionary();
        dict.add("ID", index);
        dict.add("Name", "Project " + index);
        let a: List<EntityObject> = context.Entity.getValue("Project") as List<EntityObject>;
        a.add(new EntityObject(dict));
    }
    let num = 0
    for (let index = 0; index < 20; index++) {
        let dict: Dictionary = new Dictionary();
        dict.add("ID", index);
        dict.add("Name", "Project " + index);
        if (index % 10 == 0) {
            num = ++num;
        }
        dict.add("EmployeeID", num);
        dict.add("ProjectID", num);

        let a: List<EntityObject> = context.Entity.getValue("EmployeeProject") as List<EntityObject>;
        a.add(new EntityObject(dict));
    }


    return context;
}

export class JoinTest {

    Entity?: Dictionary;
}

export interface IModel {
}

export class Employee implements IModel {

    ID?: number;

    Name?: string;

    JoiningDate?: DateTime;
}
export class EmployeeProject implements IModel {

    EmployeeID?: number;

    ProjectID?: number;
}

export class Project implements IModel {

    Name?: string;

    ID?: number;
}
